@@ -105,7 +105,7 @@ cMenuEditSearchExt::cMenuEditSearchExt(cSearchExt *SearchExt, bool New, bool Tem
     // collect content string IDs
     std::set<std::string> contentStrings;
     for (unsigned int i = 0; i < CONTENT_DESCRIPTOR_MAX; i++) {
-        const string contentDescr = cEvent::ContentToString(i);
+        const std::string contentDescr = cEvent::ContentToString(i);
         if (!contentDescr.empty() && contentStrings.find(contentDescr) == contentStrings.end()) {
             contentStrings.insert(contentDescr);
             contentStringIDs.push_back(i);
@@ -337,7 +337,7 @@ void cMenuEditSearchExt::Set()
                 if (data.allowedRepeats > 0)
                     Add(new cMenuEditIntItem(IndentMenuItem(tr("Only repeats within ... days"), 2), &data.repeatsWithinDays, 0, 999));
                 Add(new cMenuEditBoolItem(IndentMenuItem(tr("Compare title"), 2), &data.compareTitle, trVDR("no"), trVDR("yes")));
-                Add(new cMenuEditStraItem(IndentMenuItem(tr("Compare subtitle"), 3), &data.compareSubtitle, 3, CompareSubtitleModes));
+                Add(new cMenuEditStraItem(IndentMenuItem(tr("Compare subtitle"), 2), &data.compareSubtitle, 3, CompareSubtitleModes));
                 Add(new cMenuEditBoolItem(IndentMenuItem(tr("Compare summary"), 2), &data.compareSummary, trVDR("no"), trVDR("yes")));
                 if (data.compareSummary)
                     Add(new cMenuEditIntItem(IndentMenuItem(tr("Min. match in %"), 3), &data.compareSummaryMatchInPercent, 1, 100));
@@ -982,7 +982,7 @@ void cMenuCatValuesSelect::Set()
     int selCount = 0;
     Clear();
 
-    string SearchMode =  string(tr("Search mode")) + ": ";
+    std::string SearchMode =  std::string(tr("Search mode")) + ": ";
     if (searchMode == 0)
         SearchMode += tr("phrase");
     else if (searchMode == 1)
